==> haskell-hunit-1.6.2.0-427-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HUnit
version:              1.6.2.0
visibility:           public
id:                   HUnit-1.6.2.0-a0sGYhVQliLTRPu3iH7Dr
key:                  HUnit-1.6.2.0-a0sGYhVQliLTRPu3iH7Dr
license:              BSD-3-Clause
maintainer:           Simon Hengel <sol@typeful.net>
author:               Dean Herington
stability:            stable
homepage:             https://github.com/hspec/HUnit#readme
synopsis:             A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.

category:             Testing
abi:                  b906f345aba02c67969100acf5657d65
exposed:              True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text

hidden-modules:       Paths_HUnit
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/HUnit-1.6.2.0
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/HUnit-1.6.2.0
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/HUnit-1.6.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hunit
hs-libraries:         HSHUnit-1.6.2.0-a0sGYhVQliLTRPu3iH7Dr
depends:
    base-4.18.3.0 call-stack-0.4.0-D3kOb1gXhq8E84SgXdsTIH
    deepseq-1.4.8.1

haddock-interfaces:   /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html:         /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hunit-1.6.2.0-427.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HUnit
version:              1.6.2.0
visibility:           public
id:                   HUnit-1.6.2.0-3WxKawST6La9vkupaT87KS
key:                  HUnit-1.6.2.0-3WxKawST6La9vkupaT87KS
license:              BSD-3-Clause
maintainer:           Simon Hengel <sol@typeful.net>
author:               Dean Herington
stability:            stable
homepage:             https://github.com/hspec/HUnit#readme
synopsis:             A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.

category:             Testing
abi:                  efb3f88b68f10e37fd08758458e60469
exposed:              True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text

hidden-modules:       Paths_HUnit
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/HUnit-1.6.2.0
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/HUnit-1.6.2.0
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/HUnit-1.6.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hunit
hs-libraries:         HSHUnit-1.6.2.0-3WxKawST6La9vkupaT87KS
depends:
    base-4.18.3.0 call-stack-0.4.0-CNBVTySS9dB7ZkKYIwNNi0
    deepseq-1.4.8.1

haddock-interfaces:   /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html:         /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
